Function exec::execvp [] [src]

pub fn execvp<'a, S, I>(program: S, args: I) -> ExecError where S: AsRef<str>, I: IntoIterator, I::Item: AsRef<str>

Run program with args, completely replacing the currently running program. If it returns at all, it always returns an error.